@@ -2,8 +2,8 @@ import risclog.sqlalchemy.db
 import pytest
 
 
-@pytest.fixture('function')
-def database__selenium_testing(request):
+@pytest.fixture(scope='function')
+def database__selenium_testing():
     """Prepare the database for selenium testing:
 
     Remove the SQLAlchemy session after transaction.commit(). This is the same
@@ -11,11 +11,8 @@ def database__selenium_testing(request):
     tests.
     """
     db = risclog.sqlalchemy.db.get_database(testing=True)
-    extension = db.session_factory.session_factory.kw['extension']
-    old_keep_session = extension.keep_session
-    extension.keep_session = False
+    old_keep_session = db.zope_transaction_events.keep_session
+    db.zope_transaction_events.keep_session = False
 
-    def finalizer():
-        extension.keep_session = old_keep_session
-
-    request.addfinalizer(finalizer)
+    yield
+    db.zope_transaction_events.keep_session = old_keep_session
